changeset 32295:bea4ebf594c6 v9.0.1479

patch 9.0.1479: small source file problems; outdated list of distrib. files Commit: https://github.com/vim/vim/commit/f39d9e9dca443e42920066be3a98fd9780e4ed33 Author: Bram Moolenaar <Bram@vim.org> Date: Sat Apr 22 22:54:40 2023 +0100 patch 9.0.1479: small source file problems; outdated list of distrib. files Problem: Small source file problems; outdated list of distributed files. Solution: Small updates to source files and list of distributed files.
author Bram Moolenaar <Bram@vim.org>
date Sun, 23 Apr 2023 00:00:04 +0200
parents b2e8663e6dcc
children a113ead89676
files Filelist ci/load-snd-dummy.sh src/beval.c src/cmdexpand.c src/ex_cmds.c src/getchar.c src/gui_beval.c src/insexpand.c src/job.c src/menu.c src/terminal.c src/testdir/Makefile src/version.c src/vim9compile.c src/window.c
diffstat 15 files changed, 25 insertions(+), 33 deletions(-) [+]
line wrap: on
line diff
--- a/Filelist
+++ b/Filelist
@@ -18,10 +18,8 @@ SRC_ALL =	\
 		.appveyor.yml \
 		.codecov.yml \
 		ci/appveyor.bat \
-		ci/build-snd-dummy.sh \
 		ci/config.mk*.sed \
 		ci/if_ver*.vim \
-		ci/load-snd-dummy.sh \
 		ci/setup-xvfb.sh \
 		src/Make_all.mak \
 		src/README.md \
@@ -710,6 +708,7 @@ RT_ALL =	\
 		runtime/ftoff.vim \
 		runtime/gvimrc_example.vim \
 		runtime/import/dist/vimhelp.vim \
+		runtime/import/dist/vimhighlight.vim \
 		runtime/macros/README.txt \
 		runtime/macros/editexisting.vim \
 		runtime/macros/hanoi/click.me \
deleted file mode 100644
--- a/ci/load-snd-dummy.sh
+++ /dev/null
@@ -1,8 +0,0 @@
-#!/bin/bash
-set -e
-
-if ! modprobe snd-dummy; then
-    # snd-dummy is contained in linux-modules-extra (if exists)
-    apt-get install -yq --no-install-suggests --no-install-recommends "linux-modules-extra-$(uname -r)"
-    modprobe snd-dummy
-fi
--- a/src/beval.c
+++ b/src/beval.c
@@ -261,7 +261,7 @@ bexpr_eval(
     save_curbuf = curbuf;
     curbuf = wp->w_buffer;
     use_sandbox = was_set_insecurely((char_u *)"balloonexpr",
-	    *curbuf->b_p_bexpr == NUL ? 0 : OPT_LOCAL);
+				    *curbuf->b_p_bexpr == NUL ? 0 : OPT_LOCAL);
     curbuf = save_curbuf;
     if (use_sandbox)
 	++sandbox;
--- a/src/cmdexpand.c
+++ b/src/cmdexpand.c
@@ -1484,8 +1484,8 @@ addstar(
  *  EXPAND_FILES	    After command with EX_XFILE set, or after setting
  *			    with P_EXPAND set.	eg :e ^I, :w>>^I
  *  EXPAND_DIRECTORIES	    In some cases this is used instead of the latter
- *			    when we know only directories are of interest.  eg
- *			    :set dir=^I
+ *			    when we know only directories are of interest.
+ *			    E.g.  :set dir=^I  and  :cd ^I
  *  EXPAND_SHELLCMD	    After ":!cmd", ":r !cmd"  or ":w !cmd".
  *  EXPAND_SETTINGS	    Complete variable names.  eg :set d^I
  *  EXPAND_BOOL_SETTINGS    Complete boolean variables only,  eg :set no^I
--- a/src/ex_cmds.c
+++ b/src/ex_cmds.c
@@ -5107,7 +5107,8 @@ ex_global(exarg_T *eap)
 	    *cmd++ = NUL;		    // replace it with a NUL
     }
 
-    if (search_regcomp(pat, &used_pat, RE_BOTH, which_pat, SEARCH_HIS, &regmatch) == FAIL)
+    if (search_regcomp(pat, &used_pat, RE_BOTH, which_pat, SEARCH_HIS,
+							    &regmatch) == FAIL)
     {
 	emsg(_(e_invalid_command));
 	return;
--- a/src/getchar.c
+++ b/src/getchar.c
@@ -133,7 +133,7 @@ get_buffcont(
     for (bp = buffer->bh_first.b_next; bp != NULL; bp = bp->b_next)
 	count += (long_u)STRLEN(bp->b_str);
 
-    if ((count || dozero) && (p = alloc(count + 1)) != NULL)
+    if ((count > 0 || dozero) && (p = alloc(count + 1)) != NULL)
     {
 	p2 = p;
 	for (bp = buffer->bh_first.b_next; bp != NULL; bp = bp->b_next)
@@ -141,7 +141,7 @@ get_buffcont(
 		*p2++ = *str++;
 	*p2 = NUL;
     }
-    return (p);
+    return p;
 }
 
 /*
--- a/src/gui_beval.c
+++ b/src/gui_beval.c
@@ -404,8 +404,7 @@ pointer_event(BalloonEval *beval, int x,
 	}
 	else
 	{
-	    beval->timerID = g_timeout_add((guint)p_bdlay,
-		    &timeout_cb, beval);
+	    beval->timerID = g_timeout_add((guint)p_bdlay, &timeout_cb, beval);
 	}
     }
 }
--- a/src/insexpand.c
+++ b/src/insexpand.c
@@ -3001,7 +3001,7 @@ ins_compl_update_sequence_numbers(void)
 
     if (compl_dir_forward())
     {
-	// search backwards for the first valid (!= -1) number.
+	// Search backwards for the first valid (!= -1) number.
 	// This should normally succeed already at the first loop
 	// cycle, so it's fast!
 	for (match = compl_curr_match->cp_prev; match != NULL
@@ -3012,8 +3012,7 @@ ins_compl_update_sequence_numbers(void)
 		break;
 	    }
 	if (match != NULL)
-	    // go up and assign all numbers which are not assigned
-	    // yet
+	    // go up and assign all numbers which are not assigned yet
 	    for (match = match->cp_next;
 		    match != NULL && match->cp_number == -1;
 					   match = match->cp_next)
@@ -3021,7 +3020,7 @@ ins_compl_update_sequence_numbers(void)
     }
     else // BACKWARD
     {
-	// search forwards (upwards) for the first valid (!= -1)
+	// Search forwards (upwards) for the first valid (!= -1)
 	// number.  This should normally succeed already at the
 	// first loop cycle, so it's fast!
 	for (match = compl_curr_match->cp_next; match != NULL
@@ -3032,8 +3031,7 @@ ins_compl_update_sequence_numbers(void)
 		break;
 	    }
 	if (match != NULL)
-	    // go down and assign all numbers which are not
-	    // assigned yet
+	    // go down and assign all numbers which are not assigned yet
 	    for (match = match->cp_prev; match
 		    && match->cp_number == -1;
 					   match = match->cp_prev)
--- a/src/job.c
+++ b/src/job.c
@@ -383,7 +383,8 @@ get_job_options(typval_T *tv, jobopt_T *
 		val = tv_get_string(item);
 		if (STRCMP(val, "open") != 0 && STRCMP(val, "close") != 0)
 		{
-		    semsg(_(e_invalid_value_for_argument_str_str), "term_finish", val);
+		    semsg(_(e_invalid_value_for_argument_str_str),
+							   "term_finish", val);
 		    return FAIL;
 		}
 		opt->jo_set2 |= JO2_TERM_FINISH;
--- a/src/terminal.c
+++ b/src/terminal.c
@@ -3310,7 +3310,7 @@ handle_resize(int rows, int cols, void *
 }
 
 /*
- * If the number of lines that are stored goes over 'termscrollback' then
+ * If the number of lines that are stored goes over 'termwinscroll' then
  * delete the first 10%.
  * "gap" points to tl_scrollback or tl_scrollback_postponed.
  * "update_buffer" is TRUE when the buffer should be updated.
--- a/src/testdir/Makefile
+++ b/src/testdir/Makefile
@@ -18,7 +18,7 @@ REDIR_TEST_TO_NULL = --cmd 'au SwapExist
 #   The output goes into a file "valgrind.testN"
 #   Vim should be compiled with EXITFREE to avoid false warnings.
 #   This will make testing about 10 times as slow.
-# VALGRIND = valgrind --tool=memcheck --leak-check=yes --num-callers=35 --log-file=valgrind.$*
+# VALGRIND = valgrind --tool=memcheck --leak-check=yes --num-callers=45 --log-file=valgrind.$*
 
 # To execute one test, e.g. in gdb, use something like this:
 # run -f -u unix.vim --gui-dialog-file guidialog -U NONE --noplugin --not-a-term -S runtest.vim test_name.vim
--- a/src/version.c
+++ b/src/version.c
@@ -696,6 +696,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    1479,
+/**/
     1478,
 /**/
     1477,
--- a/src/vim9compile.c
+++ b/src/vim9compile.c
@@ -2646,7 +2646,7 @@ compile_assignment(
 			lhs_type = &t_number;
 		    if (*p != '=' && need_type(rhs_type, lhs_type, FALSE,
 					    -1, 0, cctx, FALSE, FALSE) == FAIL)
-		    goto theend;
+			goto theend;
 		}
 	    }
 	    else if (cmdidx == CMD_final)
--- a/src/window.c
+++ b/src/window.c
@@ -4633,7 +4633,7 @@ tabpage_index(tabpage_T *ftp)
 leave_tabpage(
     buf_T	*new_curbuf UNUSED,    // what is going to be the new curbuf,
 				       // NULL if unknown
-    int		trigger_leave_autocmds UNUSED)
+    int		trigger_leave_autocmds)
 {
     tabpage_T	*tp = curtab;
--- a/src/menu.c
+++ b/src/menu.c
@@ -2318,8 +2318,8 @@ gui_destroy_tearoffs_recurse(vimmenu_T *
 /*
  * Execute "menu".  Use by ":emenu" and the window toolbar.
  * "eap" is NULL for the window toolbar.
  * "mode_idx" specifies a MENU_INDEX_ value, use -1 to depend on the current
  * state.
  */
     void
 execute_menu(exarg_T *eap, vimmenu_T *menu, int mode_idx)
@@ -2329,7 +2329,7 @@ execute_menu(exarg_T *eap, vimmenu_T *me
     if (idx < 0)
     {
 	// Use the Insert mode entry when returning to Insert mode.
-	if (restart_edit && !current_sctx.sc_sid)
+	if (restart_edit && current_sctx.sc_sid == 0)
 	{
 	    idx = MENU_INDEX_INSERT;
 	}
@@ -2513,7 +2513,7 @@ ex_emenu(exarg_T *eap)
 {
     vimmenu_T	*menu;
     char_u	*arg = eap->arg;
-    int		mode_idx = -1;
+    int		mode_idx = MENU_INDEX_INVALID;
 
     if (arg[0] && VIM_ISWHITE(arg[1]))
     {
@@ -2318,8 +2318,8 @@ gui_destroy_tearoffs_recurse(vimmenu_T *
  * Execute "menu".  Use by ":emenu" and the window toolbar.
  * "eap" is NULL for the window toolbar.
- * "mode_idx" specifies a MENU_INDEX_ value, use -1 to depend on the current
- * state.
+ * "mode_idx" specifies a MENU_INDEX_ value, use MENU_INDEX_INVALID to depend
+ * on the current state.
  */
     void